Adding folders
Date: 07 17, 2001 11:17:46 AM

# Adding Folder Concepts

Folder concepts are used to organize multiple types of samples.

To add a folder concept to a stub:

1. In the Gram Tab, select the stub concept where you want to insert the folder concept.

2. Right click and select Add > Folder.

3. Give the folder concept a name in the dialog box.

4. Click OK to finish adding the folder concept.

Note: Folder concepts can be added to stub concepts.

Tip: Add multiple folder concepts at the same time separating the names with commas. Use the yellow up and down arrows on the Tab Toolbar to move your folder concepts.